@@ -9,7 +9,7 @@ use MIME::Base64;
 
 my $level=0; #Used to calculate indentation for pretty printing
 
-our %dcMap;
+my %dcMap;
    %dcMap = (
             'rights' => 'dc:rights',
             'coverage' => 'dc:coverage',
@@ -37,7 +37,6 @@ our %dcMap;
             'documenttype' => 'dc:type',
             'doc-rights' => 'dc:rights',
             'page-topic' => 'dc:subject',
-            'topicname' => 'dc:subject',
             'keyword' => 'dc:subject',
             'document-rights' => 'dc:rights',
             'keywords' => 'dc:subject',
@@ -60,11 +59,11 @@ our %dcMap;
 ##########################SUBS########################
 
 sub XWI2XML {
-    my ($xwi, $inclHTML, $inclCanonDoc, $collapseinLinks, $nooutLinks) = @_;
+    my ($xwi, $inclHTML, $inclCanonDoc) = @_;
     my $recordid=$xwi->recordid;
     my $Rsummary = '';
     my $md5 = $xwi->md5;
-    my $res = StartTag("documentRecord md5id=\"$md5\" id=\"$recordid\"");
+    my $res = StartTag("documentRecord id=\"$md5\"");
 
     $res .= ToXML('modifiedDate', time2iso($xwi->modifiedDate));
     $res .= ToXML('expiryDate', time2iso($xwi->expiryDate));
@@ -120,14 +119,6 @@ sub XWI2XML {
     $res .= StartTag('metaData');
     my $tit= $xwi->title;
     $res .= ToXMLAttr('meta',"name=\"title\"", $tit);
-    if ( !defined($tit) || $tit =~ /^\s*$/ ) {
-      #Empty title => generate title from text and 1st heading
-      my @ip = split(/\s+/,substr(${$xwi->text},0,100),5);
-      my ($head,$t) = split(/;/, $xwi->heading_get, 2);
-      my $ip = join(' ', $ip[0], $ip[1], $ip[2], $ip[3]);
-      if ( $ip =~ /$head/ ) { $res .= ToXMLAttr('meta',"name=\"title\"", $ip); }
-      else  { $res .= ToXMLAttr('meta',"name=\"title\"", $head . ' ' . $ip); }
-    }
     my ($name,$content);
     while (1) {
 	($name,$content) = $xwi->meta_get;
@@ -162,8 +153,7 @@ sub XWI2XML {
     $sth = $sv->prepare(qq{SELECT urlstr FROM urls WHERE urls.urlid=?;});
     my $sth1 = $sv->prepare(qq{SELECT md5 FROM recordurl WHERE urlid=?;});
     my %seen = ();
-#    while (1) {
-    while (!$nooutLinks) {
+    while (1) {
 	($urlstr, $netlocid, $urlid, $anchor, $ltype) = $xwi->link_get;
 	last unless ($urlstr || $netlocid);
 	if ( $urlstr eq '' ) {
@@ -199,11 +189,9 @@ sub XWI2XML {
 	$res .= StartTag('inlinks');
 	while (($from,$anchor,$lmd5,$ltype)=$sth->fetchrow_array) {
             $anchor = Encode::decode('utf8',$anchor);
-                next if ( defined($seen{$from,$anchor}) || ($anchor eq '') || defined($seen{$anchor}) );
+
+                next if ( defined($seen{$from,$anchor}) || ($anchor eq '') );
                 $seen{$from,$anchor}=1;
-                if ($collapseinLinks) {
-                  $seen{$anchor}=1;
-                }
                 my $s = $from;
                 $s =~ s|http://([^/:]+).*|$1|;
                 if (defined($servers{$s})) {#from same server as page, just save and put last in list
